==> pointpos_api-0.0.16.tar.gz: test/gratuity_api_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';


/// tests for GratuityApi
void main() {
  var instance = new GratuityApi();

  group('tests for GratuityApi', () {
    // Create Gratuity
    //
    // Create Gratuity
    //
    //Future<Gratuity> createGratuity(String authorization, String xAPIKey, Gratuity body, { String xPin }) async 
    test('test createGratuity', () async {
      // TODO
    });

    // Delete Gratuity By ID
    //
    // Delete Gratuity By ID
    //
    //Future deleteGratuityByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test deleteGratuityByID', () async {
      // TODO
    });

    // Get Gratuity List
    //
    // Get Gratuity  List
    //
    //Future<List<Gratuity>> findGratuity(String authorization, String xAPIKey, { String xPin, num limit, num offset, String sort, String direction, List<String> filter }) async 
    test('test findGratuity', () async {
      // TODO
    });

    // Get Gratuity By ID
    //
    // Get Gratuity By ID
    //
    //Future<Gratuity> getGratuityByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test getGratuityByID', () async {
      // TODO
    });

    // Update Gratuity By ID
    //
    // Update [object Object] By ID
    //
    //Future<Gratuity> updateGratuityByID(String authorization, String xAPIKey, String id, Gratuity body, { String xPin }) async 
    test('test updateGratuityByID', () async {
      // TODO
    });

  });
}

==> pointpos_api-0.2.1.tar.gz: test/gratuity_api_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';


/// tests for GratuityApi
void main() {
  var instance = new GratuityApi();

  group('tests for GratuityApi', () {
    // Create Gratuity
    //
    // Create Gratuity
    //
    //Future<Gratuity> createGratuity(String authorization, String xAPIKey, Gratuity body, { String xPin }) async 
    test('test createGratuity', () async {
      // TODO
    });

    // Delete Gratuity By ID
    //
    // Delete Gratuity By ID
    //
    //Future deleteGratuityByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test deleteGratuityByID', () async {
      // TODO
    });

    // Get Gratuity List
    //
    // Get Gratuity  List
    //
    //Future<List<Gratuity>> findGratuity(String authorization, String xAPIKey, { String xPin, num limit, num offset, String sort, String direction, List<String> filter, bool withDeleted }) async 
    test('test findGratuity', () async {
      // TODO
    });

    // Get Gratuity By ID
    //
    // Get Gratuity By ID
    //
    //Future<Gratuity> getGratuityByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test getGratuityByID', () async {
      // TODO
    });

    // Update Gratuity By ID
    //
    // Update [object Object] By ID
    //
    //Future<Gratuity> updateGratuityByID(String authorization, String xAPIKey, String id, Gratuity body, { String xPin }) async 
    test('test updateGratuityByID', () async {
      // TODO
    });

  });
}
